import { IConstruct } from 'constructs';
/**
 * Provides a means of storing and retrieving arbitrary data that can be
 * associated with a construct.
 */
export declare class State {
    /**
     * Gets an object that allows for interacting with the stored state of a
     * construct.
     *
     * @param scope The construct for which state information is desired.
     * @returns An object that provides a means for interacting with the stored
     * state of the construct.
     */
    static of(scope: IConstruct): State;
    /**
     * The metadata key added to the root node in a construct tree to
     * differentiate it from other construct trees that are part of the same
     * build.
     */
    private static readonly METADATA_KEY;
    /**
     * The full state data for all constructs.
     */
    private static readonly _data;
    /**
     * State is tracked by construst addresses which are always unique withing
     * the construct tree.
     *
     * As state is stored globally this can cause problems if there are multiple
     * construct tree that are part of the current application.
     *
     * To avoid collissions we generate a new UUID for each unique construct tree
     * for which state is requested. The UUID is stored as metadata on the root
     * node of the costruct tree. This allows data for the same construct tree to
     * be stored together and retrieved repeatedly as needed.
     *
     * @param scope The construct to get the store key from.
     * @returns A unique ID that represents the construct tree the given scope
     * belongs to.
     */
    private static getStoreKey;
    /**
     * The construct which is having its state managed.
     */
    private readonly _scope;
    /**
     * An ID that uniquely identifies the construct tree which the construct
     * having its state managed belongs to.
     */
    private readonly _storeKey;
    /**
     * Provides a shortcut to the state for the construct associated with the
     * state manager.
     */
    private get _store();
    /**
     * Creates a new instance of the state class.
     *
     * @param scope The construct that is having its state managed.
     */
    private constructor();
    /**
     * Ensures full global state tracking is available for the node.
     */
    private _ensureInitialized;
    /**
     * Gets the value of a key from state.
     *
     * @param key The key to get from state.
     * @param defaultValue The value to return if the requested key does not
     * exist in state.
     * @returns The value of the requested key or `defaultValue` if the requested
     * key was not found.
     */
    get(key: string, defaultValue?: any): any | undefined;
    /**
     * Sets the value of a key in state.
     *
     * @param key The key to set in state.
     * @param value The value to set for the key in state.
     * @returns The previous value for the key that was set (if one exists).
     */
    set(key: string, value: any): any | undefined;
}
